package Bin::Gen::Rand ; 

our $VERSION = "0.100" ; 
our $DATE = "2021-05-26" ; 


=encoding utf8

=head1 NAME

Bin::Li

=head1 SYNOPSIS

This module "Bin::Gen::Rand" provides Unix-like commnds for generating random numbers for several stochastic distributions. 

The provided commands are as follows: 

boxmuller cointoss horsekicks saikoro t1generate t2generate

(Use the common expert knowledge of probabilisic distributions, PLEASE! )

=head1 DESCRIPTION


=head1 SEE ALSO

=cut

1 ;